<?php
header('Content-type: text/html', true);

include_once '../includes/globals.php';
include_once '../includes/rosetta.class.php';
include_once '../includes/filesaver.class.php';
include_once '../includes/aibridge.class.php';
include_once '../includes/parseComparison.php';

if (!requiredParameters('target', 'mount', 'device', 'filename', 'category', 'advanced', 'leftFile', 'leftFileName', 'rightFile', 'rightFileName'))
{
  $outputArray = array(
    'name'  => 'Error',
    'value' => 'Some required parameters are missing');
  die(Rosetta::arrayToJSON($outputArray));
}

// See if file exists
if ((!isset($_GET['overwrite']) || $_GET['overwrite'] != 'yes') &&
    FileSaver::doesFileExist($_GET['filename'], 'html', $_GET['target'], $_GET['mount'], $_GET['device']))
{
  $outputArray = array(
    'name'  => 'Error',
    'value' => 'error:exists');
  die(Rosetta::arrayToJSON($outputArray));
}

define('LEFT_FILENAME', ($_GET['leftFileName'] == 'original') ? translate('MSG_ORIGINAL_CONFIGURATION') : $_GET['leftFileName']);
define('RIGHT_FILENAME', ($_GET['rightFileName'] == 'current') ? translate('MSG_CURRENT_CONFIGURATION') : $_GET['rightFileName']);
define('VIEW_ADVANCED', ($_GET['advanced'] == 'yes') ? true : false);
define('CHANGES_ONLY', ($_GET['changesOnly'] == 'yes') ? true : false);

$comparisonData = parseComparison($_GET['leftFile'], $_GET['rightFile'], $_GET['category']);

// Output HTML
$computerName = getComputerName();
$buildVersion = getBuildVersion();
$html = array();

$html[] = '<html>';
$html[] = '<head>';
$html[] = '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">';
$html[] = '<title>' . $computerName . '</title>';
$html[] = '<style type="text/css">';
$html[] = 'body';
$html[] = '{';
  $html[] = 'padding:10px;';
  $html[] = 'margin: 0;';
  $html[] = 'font-size:12px;';
  $html[] = 'font-family:Helvetica,Arial,sans-serif;';
$html[] = '}';
$html[] = 'table';
$html[] = '{';
  $html[] = 'margin:0;';
  $html[] = 'padding:0;'; 
  $html[] = 'border-collapse:collapse;';
  $html[] = 'border:3px solid #968F89;';
  $html[] = 'font-size:1em;';
  $html[] = 'width:100%;';
$html[] = '}';
$html[] = 'tr.header';
$html[] = '{';
  $html[] = 'background-color:#968F89;';
  $html[] = 'color:#FFF;';
  $html[] = 'font-size:1.2em;';
$html[] = '}';
$html[] = 'tr.hex td';
$html[] = '{';
  $html[] = 'font-family:monospace;';
$html[] = '}';
$html[] = 'tr.hex td.info';
$html[] = '{';
  $html[] = 'font-family:Helvetica,Arial,sans-serif;';
$html[] = '}';
$html[] = 'tr.top td';
$html[] = '{';
  $html[] = 'font-weight:bold;';
$html[] = '}';
$html[] = 'tr.message td';
$html[] = '{';
  $html[] = 'background-color:#EEE;';
  $html[] = 'font-size:1.3em;';
  $html[] = 'font-weight:bold;';
  $html[] = 'padding:5px;';
  $html[] = 'text-align:center;';
$html[] = '}';
$html[] = 'td,th';
$html[] = '{';
  $html[] = 'border-bottom:1px solid #999;';
  $html[] = 'text-align:left;';
  $html[] = 'padding-left:2px;';
$html[] = '}';
$html[] = '.changed';
$html[] = '{';
  $html[] = 'background-color:#FFC;';
  $html[] = 'font-style:italic;';
$html[] = '}';
$html[] = '.info';
$html[] = '{';
  $html[] = 'color:#00F;';
  $html[] = 'font-weight:bold;';
$html[] = '}';
$html[] = '</style>';
$html[] = '</head>';
$html[] = '<body>';

if ($buildVersion != '')
  $html[] = ('<i>HP Insight Diagnostics ' . translate('MSG_VERSION') . ' ' . $buildVersion . '</i><br>');

if ($computerName != '')
  $html[] = (translate('MSG_COMPUTER_NAME') . ': <b>' . $computerName . '</b>');

$html[] = ('<br><span class="changed">' . translate('MSG_CHANGE_IN_CONFIGURATION') . '</span>');
$html[] = '<table>';

if ($comparisonData == 0)
{
  $html[] = '<tr class="message">';
  $html[] = ('<td>' . translate('MSG_NO_CHANGES_FOUND') . '</td>');
  $html[] = '</tr>';
}
else
{
  $categoryCount = count($comparisonData);
  foreach ($comparisonData as $category)
  {
    if (CHANGES_ONLY === false || $category['containsNestedChanges'] === true)
    {
      if ($categoryCount > 1)
        outputHeader($html, $category['caption']);
      foreach ($category['children'] as $child)
      {
        if (shouldDisplayChild($child))
        {
          $sublevel = ($categoryCount > 1) ? 1 : 0;
          outputData($html, $child, $sublevel);
        }
      }
    }
  }
}

function outputHeader(&$html, $caption)
{
  $html[] = '<tr class="header">';
  $html[] = '<th>' . $caption . '</th>';
  $html[] = '<th>' . LEFT_FILENAME . '</th>';
  $html[] = '<th>' . RIGHT_FILENAME . '</th>';
  $html[] = '</tr>';
}

function outputData(&$html, &$child, $sublevel)
{
  if ($sublevel == 0)
  {
    outputHeader($html, $child['caption']);
  }
  else
  {
    if (CHANGES_ONLY === false || $child['compareResult'] != 'unchanged')
    {
      switch ($child['compareResult'])
      {
      case 'added':
        outputAddedData($html, $child['caption'], $child['right'], $child['isHexData'], $sublevel);
        break;
      case 'removed':
        outputRemovedData($html, $child['caption'], $child['left'], $child['isHexData'], $sublevel);
        break;
      default:
        outputStandardData($html, $child, $sublevel);
      }
    }
  }
  foreach ($child['children'] as $nextChild)
  {
    if (shouldDisplayChild($nextChild))
    {
      $sublevel++;
      outputData($html, $nextChild, $sublevel);
      $sublevel--;
    }
  }
}

function outputAddedData(&$html, $caption, $value, $isHexData, $sublevel)
{
  $padding = ($sublevel > 1) ? (15 * ($sublevel - 1)) : 2;
  $class = array('changed');
  if ($isHexData === true)
    $class[] = 'hex';
  if ($sublevel == 1)
    $class[] = 'top';
  $html[] = '<tr class="' . implode(' ', $class) . '">';
  $html[] = ('<td style="padding-left:' . $padding . 'px">' . $caption . '</td>');
  $html[] = ('<td class="info">(' . translate('MSG_ADDED') . ')</td>');
  $html[] = ('<td>' . $value . '</td>');
  $html[] = '</tr>';
}

function outputRemovedData(&$html, $caption, $value, $isHexData, $sublevel)
{
  $padding = ($sublevel > 1) ? (15 * ($sublevel - 1)) : 2;
  $class = array('changed');
  if ($isHexData === true)
    $class[] = 'hex';
  if ($sublevel == 1)
    $class[] = 'top';
  $html[] = '<tr class="' . implode(' ', $class) . '">';
  $html[] = '<tr class="changed">';
  $html[] = ('<td style="padding-left:' . $padding . 'px">' . $caption . '</td>');
  $html[] = ('<td>' . $value . '</td>');
  $html[] = ('<td class="info">(' . translate('MSG_REMOVED') . ')</td>');
  $html[] = '</tr>';
}

function outputStandardData(&$html, &$child, $sublevel)
{
  $padding = ($sublevel > 1) ? (15 * ($sublevel - 1)) : 2;
  $class = array();
  if ($child['compareResult'] != 'unchanged')
    $class[] = 'changed';
  if ($child['isHexData'] === true)
    $class[] = 'hex';
  if ($sublevel == 1)
    $class[] = 'top';
  $html[] = '<tr class="' . implode(' ', $class) . '">';
  $html[] = ('<td style="padding-left:' . $padding . 'px">' . $child['caption'] . '</td>');
  $html[] = ('<td>' . $child['left'] . '</td>');
  $html[] = ('<td>' . $child['right'] . '</td>');
  $html[] = '</tr>';
}

function shouldDisplayChild($child)
{
  $returnVal = false;
  if (CHANGES_ONLY === false || $child['compareResult'] != 'unchanged' || $child['containsNestedChanges'] === true)
  {
    if (VIEW_ADVANCED === true || $child['isAdvanced'] === false || $child['compareResult'] != 'unchanged' || $child['containsNestedChanges'] === true)
      $returnVal = true;
  }
  return $returnVal;
}

$html[] = '</body>';
$html[] = '</html>';

$saveResult = FileSaver::saveArrayToFile($_GET['filename'], 'html', $_GET['target'], $_GET['mount'], $_GET['device'], $html);

if ($saveResult == 'success')
{
  exit('0');
}
else
{
  $outputArray = array(
    'name'  => 'Error',
    'value' => $saveResult);
  die(Rosetta::arrayToJSON($outputArray));
}

//*/
?>
