<?php
  header('Content-type: text/html; charset=utf-8', true);
  header('Cache-control: no-cache', true);
  header('Pragma: no-cache');

  include_once '../includes/globals.php';
  include_once '../includes/aibridge.class.php';
  include_once '../includes/rosetta.class.php';
  
  $result = AIBridge::getProcessResult($_GET['processID']);

  $xml = new DomDocument($result);
  $xpath = xpath_new_context($xml->document_element());
  $diagnosisResults = @xpath_eval($xpath, '/diagOutput/diagnosisResult');

  $actions = array();
  $resultOutput = array('<div id="diagnoseResult">');
  foreach ($diagnosisResults->nodeset as $diagnosisResult)
  {
    $caption = $diagnosisResult->get_attribute('caption');
    $results = @ xpath_eval($xpath, '/diagOutput/diagnosisResult[@caption="' . $caption . '"]/diagnosisResult');
    $resultOutput[] = ('<h2>' . $caption . '</h2>');
    foreach ($results->nodeset as $result)
    {
      $caption = $result->get_attribute('caption');
      $component = $result->get_attribute('component');
      $state = $result->get_attribute('currentState');

      $resultOutput[] = ('<h3>' . $caption . '</h3>');
      $resultOutput[] = '<p class="result">';
      if ($state == 'passed')
      {
        $resultOutput[] = '<img class="icon" src="../images/status_passed.gif" />';
        $resultOutput[] = translate('MSG_PASSED');
      }
      else if ($state == 'failed')
      {
        $resultOutput[] = '<img class="icon" src="../images/status_failed.gif" />';
        $resultOutput[] = translate('MSG_FAILED');
        $errors = $result->get_elements_by_tagname('error');
        if (count($errors) > 0)
        {
          $resultOutput[] = '<table class="errors">';
          foreach ($errors as $error)
          {
            $errorCaption = $error->get_attribute('caption');
            $errorTime = $error->get_attribute('time');
            $errorCode = $error->get_attribute('code');
            $resultOutput[] = '<tr>';
            $resultOutput[] = ('<th>' . $errorTime . '</th>');
            $resultOutput[] = ('<td>' . $errorCode . ': </td>');
            $resultOutput[] = ('<td>' . $errorCaption . '</td>');
            $resultOutput[] = '</tr>';
          }
          $resultOutput[] = '</table>';
        }
      }
      $resultOutput[] = '</p>';

      $infos = $result->get_elements_by_tagname('info');
      foreach ($infos as $info)
      {
        $infoCaption = $info->get_attribute('caption');
        $resultOutput[] = '<p class="infoCaption">';
        $resultOutput[] = '<img class="icon" src="../images/status_unknown.gif" />';
        $resultOutput[] = $infoCaption;
        $resultOutput[] = '</p>';
      }

      $files = $result->get_elements_by_tagname('formattedTextFile');
      foreach ($files as $file)
      {
        $filepath = (DIAGS_DIRECTORY . LANG . '/' . $file->get_attribute('filename'));
        if (file_exists($filepath))
          $resultOutput[] = ('<div class="formattedText">' . file_get_contents($filepath) . '</div>');
        else
          $resultOutput[] = ('<div class="formattedText">' . $filepath . '</div>');
      }

      reset($infos);
      foreach ($infos as $info)
      {
        $infoContent = $info->get_content();
        $resultOutput[] = ('<p class="infoContent">' . $infoContent . '</p>');
      }

      $deviceActions = $result->get_elements_by_tagname('deviceAction');
      foreach ($deviceActions as $action)
      {
        $actionArray = array();
        $actionCaption = $action->get_attribute('caption');
        $actionArray['caption'] = $actionCaption;
        $actionArray['component'] = $action->get_attribute('component');
        $actionArray['device'] = $action->get_attribute('device');
        $actionArray['subDevice'] = $action->get_attribute('subDevice');
        $actionArray['tcLoadFilename'] = ($component . '.dat');
        $actionArray['call'] = extractActionCall($action);
        $actions[] = $actionArray;
        $actionID = (count($actions) - 1);
        $resultOutput[] = ('<div class="subbutton" onclick="performAction(' . $actionID . ');">' . $actionCaption . '</div><br class="clear" />');
      }
      $resultOutput[] = '<hr>';
    }
  }
  $output = array();
  appendViewHeader($output);
  $output[] = '<script type="text/javascript" src="js/diagnoseResult.js"></script>';
  $output[] = '<script type="text/javascript">';
  $output[] = ('DEVICE_ACTIONS = ' . Rosetta::arrayToJSON($actions) . ";\n");
  $output[] = '</script>';
  $output[] = '</head>';
  $output[] = '<body onload="init();">';
  $output[] = implode('', $resultOutput);
  appendViewFooter($output);
  echo implode('', $output);

  // UTILITY FUNCTIONS

  function extractActionCall($action)
  {
    $returnVal = '';
    $actionCalls = $action->child_nodes();
    foreach ($actionCalls as $call)
    {
      if ($call->node_type() == XML_ELEMENT_NODE)
        $returnVal = $call->tagname;
    }
    return $returnVal;
  }

  /*
    {
      $test = $record->get_attribute('testCaption');
      $testTime = $record->get_attribute('testTime');
      $passedCount = $record->get_attribute('passedCount'); 
      $failedCount = $record->get_attribute('failedCount');
      $recordXpath = xpath_new_context($record);
      $numberOfTimesTested = $passedCount + $failedCount;
      $testCompletionNodes = xpath_eval($recordXpath, '/testCompletion');
      $numberOfTestCompletions = count($testCompletionNodes->nodeset);
      if ($numberOfTestCompletions <= 0)
      {
        $testCompletionNodes = xpath_eval($recordXpath, '/testCompletetion');
        $numberOfTestCompletions = count($testCompletionNodes->nodeset);
      }
      if ($numberOfTestCompletions <= 0)
	{
        $lastCompletion = '';
        $src = '../images/status_unknown.gif';
      }
      else
      {
        $lastTestCompletion = $testCompletionNodes->nodeset[$numberOfTestCompletions - 1];
        $lastCompletion = $lastTestCompletion->get_attribute('completionTime');
        $result = $lastTestCompletion->get_attribute('result');
        if ($result == 'passed')
          $src = '../images/status_passed.gif';
        else if ($result == 'failed')
          $src = '../images/status_failed.gif';
        else
          $src = '../images/status_unknown.gif';
      }
      
      $output[] = '<tr>';
      $output[] = ('<td class="icon"><img src="' . $src . '" /></td>');
      $output[] = ('<td class="test">' . $test . '</td>');
      $output[] = ('<td class="number">' . $numberOfTimesTested . '</td>');
      $output[] = ('<td class="failed">' . $failedCount . '</td>');
      $output[] = ('<td class="time">' . $testTime . '</td>');
      $output[] = ('<td class="last">' . $lastCompletion . '</td>');
      $output[] = '</tr>';
    }
    $output[] = '</tbody>';
  }

  $output[] = '</table>';
  outputViewFooter();
  //*/
?>
