<?php
  header('Content-type: text/html; charset=utf-8', true);
  header('Cache-control: no-cache', true);
  header('Pragma: no-cache');

  include_once '../includes/globals.php';
  
  // get all error xml files
  chdir(DIAGS_DIRECTORY);
  $errorFiles = glob('*.err.xml');
  $errorCodes = array();
  foreach($errorFiles as $filename)
  {
    $filepath = (DIAGS_DIRECTORY . $filename);
    // Try to make file into a DomDocument
    $xml = @ new DomDocument(file_get_contents($filepath));
    if ($xml)
    {
      $document = $xml->document_element();
    }
    else
    {
      exit('ERROR - ' . $filepath . ': invalid xml');
    }
    
    $xpath = xpath_new_context($document);
    $devices = @ xpath_eval($xpath, '/device');
    foreach($devices->nodeset as $device)
    {
      $deviceName = $device->get_attribute('caption');
      $xpath = xpath_new_context($device);
      $tests = @ xpath_eval($xpath, '/test');
      foreach($tests->nodeset as $test)
      {
        $testName = $test->get_attribute('caption');
        $xpath = xpath_new_context($test);
        $errors = @ xpath_eval($xpath, '/error');
        foreach($errors->nodeset as $error)
        {
          $errorArray = array();
          $errorArray['device'] = $deviceName;
          $errorArray['test'] = $testName;
          $errorArray['code'] = $error->get_attribute('code');;
          $messageName = $error->get_attribute('message');
          $repairName = $error->get_attribute('repair');
          if ($filepath == 'sdl.err.xml')
            $messageValue = translate('MSG_NOT_APPLICABLE');
          else
            $messageValue = translate('MSG_UNDEFINED');
          $xpath = xpath_new_context($document);
          $messageElements = @ xpath_eval($xpath, ('/message[@name="' . $messageName . '"]'));
          if (count($messageElements->nodeset) > 0)
            $messageValue = $messageElements->nodeset[0]->get_content(); // if we found message elements, we only look at the first one
          $repairElements = @ xpath_eval($xpath, ('/repair[@name="' . $repairName . '"]'));
          if (count($repairElements->nodeset) > 0)
            $repairValue = $repairElements->nodeset[0]->get_content();
          else
            $repairValue = translate('MSG_UNDEFINED');
          $errorArray['message'] = $messageValue;
          $errorArray['repair'] = $repairValue;
          $errorCodes[$errorArray['code']] = $errorArray;
        }
      }
    }
  }
  ksort($errorCodes, SORT_STRING); // sort the array by key
  //$errorCodes['index'] = Rosetta::arrayToJSON(array_keys($errorCodes['data']), true); // make an index with the keys

  outputViewHeader();
  echo '<script type="text/javascript" src="../js/lib.js"></script>';
  echo '<script type="text/javascript" src="js/errorCodes.js"></script>';
  echo '</head>';
  echo '<body onload="init();">';
  echo '<table id="errorCodes">';
  
  if (count($errorCodes) <= 0)
  {
    echo '<tr class="message">';
    echo ('<td>' . translate('MSG_NO') . ' ' . translate('MSG_ERROR_CODES') . '</td>');
    echo '</tr>';
  }
  else
  {
    echo '<thead>';
    echo '<tr>';
    echo ('<th class="code">' . translate('MSG_CODE') . '</th>');
    echo ('<th class="device">' . translate('MSG_DEVICE') . ', ' . translate('MSG_TEST') . '</th>');
    echo ('<th class="message">' . translate('MSG_MESSAGE') . '</th>');
    echo ('<th class="repair">' . translate('MSG_REPAIR') . '</th>');
    echo '</tr>';
    echo '</thead>';
    echo '<tbody>';
    foreach ($errorCodes as $error)
    {
      //$error = $errorCode['value'];
      echo ('<tr id="code' . $error['code'] . '">');
      echo ('<td class="code">' . $error['code'] . '</td>');
      echo ('<td class="device">' . $error['device'] . ',<br>' . $error['test'] . '</td>');
      echo ('<td class="message">' . $error['message'] . '</td>');
      echo ('<td class="repair">' . $error['repair'] . '</td>');
      echo '</tr>';
    }
    echo '</tbody>';
  }
  
  echo '</table>';
  outputViewFooter();
  //*/
?>
